function qft_con

% QFT_CON Show the help for the functions in this toolbox.

% This file is automatically generated.  Matthew Simoneau, 09-04-98
% Copyright (c) 1984-98 by The MathWorks, Inc. All Rights Reserved
% $Revision: 1.11 $ $Date: 1998/10/16 23:19:37 $

helpwin('qft_con/Contents');

function Contents
%MATLAB Tour Partial Function Help:  qft_con
%
%Double click on any function for more information
%
%  QFT Control Design Toolbox.
%  Version 1.0.3 (R11) 21-Nov-1997
% 
%  Specialized X-Y Graphs.
%    plotbnds  - Nichols plot of bounds.
%    plottmpl  - Nichols plot of templates.
% 
%  Bound Computation Managers.
%    sisobnds  - Single-Input/Single-Output bound computation.
%    genbnds   - General bound computation.
% 
%  Integrated Development Environments.
%    lpshape   - Continuous-time controller design.
%    dlpshape  - Discrete-time controller design.
%    pfshape   - Continuous-time pre-filter design.
%    dpfshape  - Discrete-time pre-filter design.
% 
%  Analysis.
%    chksiso   - Compare design to SISO specifications.
%    chkgen    - Compare design to general specifications.
% 
%  Arithmetic.
%    addcp     - Addition of frequency response sets.
%    addnd     - Addition of transfer function num/den sets.
%    clcp      - Closed-loop of frequency response sets.
%    clnd      - Closed-loop of transfer function num/den sets.
%    mulcp     - Multiplication of frequency response sets.
%    mulnd     - Multiplication of transfer function num/den sets.
% 
%  General Utility.
%    freqcp    - Continuous-time frequency response of num/den matrix.
%    dfreqcp   - Discrete-time frequency response of num/den matrix.
%    qftdefs   - User-defined defaults.
%    putqft    - Interactively set IDE MAT-file.
%    getqft    - Interactively retrieve IDE MAT-file.
%    cp2mp     - Complex to magnitude and phase.
%    mp2cp     - Magnitude and phase to complex.
%-------------------------------------------
%
%  QFT Control Design Toolbox Demos
% 
%  Demonstration Facility.
%    qftdemo   - Demonstration facility.
% 
%  Examples.
%    qftex1    - Main Example.
%    qftex2    - QFT Tracking.
%    qftex3    - Non-Parametric Uncertainty.
%    qftex4    - Classical Design for Fixed Plant.
%    qftex5    - ACC Benchmark.
%    qftex6    - Missile.
%    qftex7    - Cascaded: Inner-Outer.
%    qftex8    - Cascaded: Outer-Inner.
%    qftex9    - Uncertain Flexible Mechanism.
%    qftex10   - Inverted Pendulum.
%    qftex11   - Active Vibration Isolation.
%    qftex12   - Main Example (Discrete-time).
%    qftex13   - QFT Tracking (Discrete-time).
%    qftex14   - CD Mechanism (Sampled-data).
%    qftex15   - 2x2 MIMO.
%

function plotbnds
%MATLAB Tour Partial Function Help:  qft_con
%
%  PLOTBNDS Plot QFT bounds.
%           PLOTBNDS(BNDS,PTYPE,PHS) plots the QFT bounds in BNDS that are
%           associated with PTYPE and PHS.  PHS is the same phase vector used
%           for computing BNDS with SISOBNDS(PTYPE,...) and GENBNDS(PTYPE,...).
% 
%           PLOTBNDS(BNDS) plots all the QFT bounds in BNDS that were computed
%           using the default PHS.
% 
%           PLOTBNDS(BNDS,[],PHS) plots the QFT bounds in BNDS that were computed
%           using PHS and uses default value for PTYPE (all problems).
% 
%           

function plottmpl
%MATLAB Tour Partial Function Help:  qft_con
%
%  PLOTTMPL Plot frequency response templates.
%           PLOTTMPL(W,WBD,P,NOM) plots the frequency response data, P,
%           which was computed at the freguencies in WBD.  NOM
%           designates the location of the nominal plant within the
%           set, P.
% 
%           PLOTTMPL(W,[],P) uses the default values for WBD (all frequencies
%           in W) and NOM (the first row)
% 
%           

function sisobnds
%MATLAB Tour Partial Function Help:  qft_con
%
%  SISOBNDS Compute Single-Input/Single-Output QFT bounds.
%           SISOBNDS(PTYPE,W,WBD,WS,P,R,NOM,C,LOC,PHS) computes bounds for the
%           closed-loop configuration designated by PTYPE.  W is the entire
%           set of frequencies and WBD is a subset of W designating bounds to
%           compute.  WS is the performance specification, P is the frequency
%           response data of the plant (complex), R is the disk radius for
%           non-parametric uncertainty, NOM designates the nominal plant and
%           controller.  LOC specifies location of unknown controller in the
%           loop: 1 for G, 2 for H.  PHS specifies at which phases (degrees)
%           to compute bounds.
% 
%           For HELP on individual problem types, type 'help sisobnd#' where #
%           ranges from 1-9
% 
%           

function genbnds
%MATLAB Tour Partial Function Help:  qft_con
%
%  GENBNDS Compute General QFT bounds.
%          GENBNDS(PTYPE,W,WBD,WS,A,B,C,D,Pnom,PHS) computes bounds for the
%          configuration designated by PTYPE.  W is the entire set of
%          frequencies and WBD is a subset of W designating bounds to compute.
%          WS is the performance specification. A, B, C and D are
%          the frequency response data sets, Pnom designates the actual
%          nominal plant values for the configuration. PHS specifies at which
%          phases (degrees) to compute bounds.
% 
%          For HELP on individual problem types, type 'help genbnd#' where #
%          ranges from 10-11
% 
%          

function lpshape
%MATLAB Tour Partial Function Help:  qft_con
%
%  LPSHAPE Controller design environment for continuous-time linear systems.
%          LPSHAPE produces a continuous-time Nichols plot using default
%          settings.
% 
%          LPSHAPE(W,BDB,NUMP0,DENP0,DELAY,NUMC0,DENC0,PHS) produces the
%          Nichols plot design environment with the nominal plant transfer
%          function P0(s)=NUMP0(s)/DENP0(s) where NUMP0 and DENP0 contain
%          the polynomial coefficients in descending powers of s using the
%          user-supplied frequency vector W.  BDB contains the QFT bounds,
%          NUMC0 and DENC0 contain the coefficients for the initial
%          controller, and PHS is the user-defined phase vector.
% 
%          Default values can be used for many of the inputs. For example,
%          LPSHAPE(W,[],P0,[]) produces the nichols plot as above,
%          yet without the bounds and P0 is now in complex number format.
%          W corresponds to the frequency vector used to compute P0.  The
%          rest of the inputs are set to their defaults. DELAY (0),
%          NUMC0 (1), DENC0 (1), PHS (0:-5:360).
% 
%          

function dlpshape
%MATLAB Tour Partial Function Help:  qft_con
%
%  DLPSHAPE Controller design environment for discrete-time linear systems.
%           DLPSHAPE(T) produces a Discrete Nichols plot using default
%           settings.
% 
%           DLPSHAPE(T,W,BDB,NUMP0,DENP0,NUMC0,DENC0,PHS) produces the
%           Nichols plot design environment with the nominal plant transfer
%           function P0(z)=NUMP0(z)/DENP0(z) where NUMP0 and DENP0
%           contain the polynomial coefficients in descending powers of z
%           using the user-supplied frequency vector W.  BDB contains the
%           QFT bounds, NUMC0 and DENC0 contain the coefficients for the
%           initial controller, and PHS is the user-defined phase vector
% 
%           Default values can be used for many of the inputs. For example,
%           DLPSHAPE(T,W,[],P0,[]) produces the nichols plot as above,
%           yet without the bounds and P0 is now in complex number format.
%           W corresponds to the frequency vector used to compute P0.  The
%           rest of the inputs are set to their defaults. NUMC0 (1),
%           DENC0 (1), PHS (0:-5:360).
% 
%           

function pfshape
%MATLAB Tour Partial Function Help:  qft_con
%
%  PFSHAPE Pre-Filter design environment for continuous-time linear systems.
%          PFSHAPE(PTYPE) creates a continuous filter CAD environment using
%          default settings. PTYPE designates the closed-loop configuration.
% 
%          PFSHAPE(PTYPE,W,WBD,WS,P,R,G,H,NUMF0,DENF0) creates the environment
%          with the frequency set WBD (WBD is a subset of W), performance
%          specifications WS, plant complex matrix P, uncertainty disk
%          radius matrix R, controller matrices G and H, and an initial
%          filter design F(s)=NUMF0(s)/DENF0(s) where NUMF0 and DENF0 contain
%          the polynomial coefficients in descending powers of s.
% 
%          Default values can be used for many of the inputs. For example,
%          PFSHAPE(PTYPE,W,WBD,WT,P,[],G) creates the environment as above,
%          except the default values are used for R (0), H (1), NUMF0 (1),
%          and DENF0 (1).
% 
%          

function dpfshape
%MATLAB Tour Partial Function Help:  qft_con
%
%  DPFSHAPE Pre-Filter design environment for discrete-time linear systems.
%           DPFSHAPE(T,PTYPE) creates a discrete filter CAD environment using
%           default settings.  T is the sampling period in seconds and
%           PTYPE designates which closed-loop configuration.
% 
%           DPFSHAPE(T,PTYPE,W,WBD,WS,P,R,G,H,NUMF0,DENF0) creates the
%           environment with the frequency set WBD (WBD is a subset of W),
%           performance specifications WS, plant complex matrix P,
%           uncertainty disk radius matrix R, controller matrices G and H,
%           and an initial filter design F(z)=NUMF0(z)/DENF0(z) where NF0
%           and DF0 contain the polynomial coefficients in descending powers
%           of z.
% 
%           Default values can be used for many of the inputs. For example,
%           DPFSHAPE(T,PTYPE,W,WBD,WS,P,[],G,[],NUMF0,DENF0) creates the
%           environment as above, except the default values are
%           used for R (0) and H (1).
% 
%           

function chksiso
%MATLAB Tour Partial Function Help:  qft_con
%
%  CHKSISO Analyze closed-loop response with respect to specifications.
%          CHKSISO(PTYPE,W,WS,P,R,G,H,F) produces the magnitude plot
%          of the closed-loop response and WS over the frequency vector
%          W.
% 
%          When invoked with a left-hand argument
%          [ERR]=CHKSISO(PTYPE,W,WS,P,R,G,H,F) returns the difference
%          between the closed-loop and WS in the vector ERR.  No plot
%          is drawn.

function chkgen
%MATLAB Tour Partial Function Help:  qft_con
%
%  CHKGEN Check closed-loop response with respect to specifications.
%         CHKGEN(PTYPE,W,WS,A,B,C,D,G) produces the magnitude plot
%         of the closed-loop response and WS over the frequency vector
%         W.
% 
%         When invoked with a left-hand argument
%         [ERR]=CHKGEN(PTYPE,W,WS,A,B,C,D,G) returns the difference
%         between the closed-loop and WS in the vector ERR.  No plot
%         is drawn.

function addcp
%MATLAB Tour Partial Function Help:  qft_con
%
%  ADDCP Addition of two complex matrices.
%        ADDCP(P1,P2) produces the corrleated addition of P1 and P2.
% 
%        ADDCP(P1,P2,FLAG) produces the user-specified addition of P1 and P2.
%        FLAG = 1 for corrleated; FLAG = 2 for uncorrelated
% 
%        ADDCP assumes P1 and P2 have the same number of columns.
%        ADDCP automatically handles the case of either P1 or P2
%        being only one row.
% 
%        

function addnd
%MATLAB Tour Partial Function Help:  qft_con
%
%  ADDND Addition of two numerator and denominator matrices.
%        ADDND(P1N,P1D,P2N,P2D) produces the correlated addition of P1N,P1D,
%        P2N,P2D.  P1N, P2N are matrices containing the numerators of P1 and
%        P2. P1D,P2D are matrices containing the denominators of P1 and P2.
% 
%        ADDND(P1N,P1D,P2N,P2D,FLAG) produces the user-specified addition of
%        P1N,P1D,P2N,P2D. FLAG = 1 for corrleated; FLAG = 2 for uncorrelated
% 
%        ADDND automatically handles the case of either P1N,P1D or P2N,P2D
%        being only one row.
% 
%        

function clcp
%MATLAB Tour Partial Function Help:  qft_con
%
%  CLCP Computation of various closed-loop configurations.
%       [CL]=CLCP(PROB,P,G,H,F,SGN) produces the corrleated
%       computation of the closed-loop specified by PROB.
% 
%       [CL]=CLCP(PROB,P,G,H,F,SGN,UTYPE) produces the user-specified
%       computation of the closed-loop specified by PROB.
%       UTYPE = 1 for corrleated; UTYPE = 2 for uncorrelated
% 
%       CLCP assumes P, G, H, and F have the same number of columns;
%       except if any of the above are only a single number.
%       CLCP automatically handles the case of either P, G, or H
%       being only one row.
% 
%       F can only be a scalar or row vector.
% 
%       

function clnd
%MATLAB Tour Partial Function Help:  qft_con
%
%  CLND Computation of various closed-loop configurations for num/den matrices.
%       [NUMCL,DENCL]=CLND(PROB,NP,DP,NG,DG,NH,DH,NF,DF) produces the
%       correlated computation of the user-specified closed-loop configuration
%       in PROB.  NUMCL and DENCL contain the closed-loop transfer functions
%       in descending powers of s
% 
%       [NUMCL,DENCL]=CLND(PROB,NP,DP,NG,DG,NH,DH,NF,DF,SGN,FLAG) produces
%       the user-specified computation of the user-specified closed-loop
%       configuration in PROB.  SGN is the sign of the feedback loop.
%       FLAG = 1 for corrleated; FLAG = 2 for uncorrelated
% 
%       CLND automatically handles the case when either NP,DP,NG,DG, or
%       NH,DH are only one row.
% 
%       *** NF,DF can only be one row.***
% 
%       

function mulcp
%MATLAB Tour Partial Function Help:  qft_con
%
%  MULCP Multiplication of two complex matrices.
%        MULCP(P1,P2) produces the corrleated multiplication of P1 and P2.
% 
%        MULCP(P1,P2,FLAG) produces the user-specified multiplication of P1
%        and P2.  FLAG = 1 for corrleated; FLAG = 2 for uncorrelated.
% 
%        MULCP assumes P1 and P2 have the same number of columns.
%        MULCP automatically handles the case of either P1 or P2
%        being only one row.
% 
%        

function mulnd
%MATLAB Tour Partial Function Help:  qft_con
%
%  MULND Multiplication of two numerator and denominator matrices.
%        MULND(P1N,P1D,P2N,P2D) produces the correlated multiplication of P1N,P1D,
%        P2N,P2D.  P1N, P2N are matrices containing the numerators of P1 and
%        P2. P1D,P2D are matrices containing the denominators of P1 and P2.
% 
%        MULND(P1N,P1D,P2N,P2D,FLAG) produces the user-specified multiplication
%        of P1N,P1D,P2N,P2D. FLAG = 1 for corrleated;  FLAG = 2 for
%        uncorrelated
% 
%        MULND automatically handles the case of either P1N,P1D or P2N,P2D
%        being only one row.
% 
%        

function freqcp
%MATLAB Tour Partial Function Help:  qft_con
%
%  FREQCP Compute continuous bode of numerator/denominator matrices.
%         CP=FREQCP(NUM,DEN,W,DELAY) returns the continuous bode of the
%         numerators and denominators in NUM and DEN, respectively.  W is
%         the frequency vector in radians/second.  DELAY is the pure
%         time delay and it must have as many rows as NUM or DEN or be
%         just one element.
% 
%         CP=FREQCP(NUM,DEN,W) returns the continuous bode as above,
%         except DELAY defaults to zero (0).
% 
%         Rows and columns of NUM and DEN correspond to cases and
%         coefficients, respectively.
% 
%         Rows and columns of CP correspond to cases and frequencies,
%         respectively.

function dfreqcp
%MATLAB Tour Partial Function Help:  qft_con
%
%  DFREQCP Compute discrete bode of numerator/denominator matrices.
%          CP=DFREQCP(T,NUM,DEN,W) returns the discrete bode of the numerators
%          and denominators in NUM and DEN, respectively. T is the sampling
%          period in seconds and W is the frequency vector in radians/second.
% 
%          Rows and columns of NUM and DEN correspond to cases and coefficients,
%          respectively.
% 
%          Rows and columns of CP correspond to cases and frequencies,
%          respectively.

function qftdefs
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTDEFS  User-defined QFT Toolbox default values.
% 
%           The purpose of this file is to allow the user to change defaults
%           related to bound computations and the shaping environment.
% 
%           Use your text editor to change the values within this file for
%           default values which you wish to customize.

function putqft
%MATLAB Tour Partial Function Help:  qft_con
%
%  PUTQFT Interactively set QFT element matrix to mat-file.
%         PUTQFT(Ts,NUM,DEN) creates a dialog box that interactively allows
%         for the naming of the desired mat-file.  Ts is the sampling time
%         and NUM and DEN represent the transfer function with descending
%         powers of s or z.  This mat-file can then be opened by any of the
%         shaping environments.
% 
%         PUTQFT(Ts,Z,P,K) interactively places the Zero/Pole/Gain format
%         into a mat-file that can be opened by the shaping environments.
% 
%         PUTQFT(Ts,A,B,C,D) interactively places the State-Space format into
%         a mat-file that can be opened by the shaping environments.
% 
%         PUTQFT(FNAME,Ts,...) directly writes the passed format into the
%         file specified by the string variable FNAME (i.e. 'myfile.mat').
% 
%         Note: Ts MUST be specified in all cases.
%               For continuous-time, Ts equals [].
%               For discrete-time, Ts > 0.
% 
%         The shaping environments look for files with the following
%         extensions:
%               LPSHAPE  - *.shp
%               DLPSHAPE - *.dsh
%               PFSHAPE  - *.fsh
%               DPFSHAPE - *.dfs
% 
%         

function getqft
%MATLAB Tour Partial Function Help:  qft_con
%
%  GETQFT Interactively retrieve QFT element matrix from mat-file.
%         [NUM,DEN]=GETQFT places the contents of the chosen file into the
%         numerator/denominator format.  Elements in NUM and DEN are in
%         descending powers of s.
% 
%         [Z,P,K]=GETQFT places the contents of the chosen file into the
%         zero/pole/gain format.  Z contains the zeros, P contains the poles,
%         and K contains the D.C. gain.
% 
%         [A,B,C,D]=GETQFT places the contents into a balanced form.
% 
%         [...,Ts]=GETQFT returns the desired discrete-time format and the
%         sampling-time, Ts.
% 
%         [...]=GETQFT(FNAME) reads directly from the filename specified
%         by FNAME.  FNAME must be in quotes i.e. 'filename.shp'
% 
%         FNAME can also be one of the file extensions associated with
%         a shaping environment. i.e. '*.shp'
% 
%         The shaping environments create files with the following
%         extensions:
%               LPSHAPE  - *.shp
%               DLPSHAPE - *.dsh
%               PFSHAPE  - *.fsh
%               DPFSHAPE - *.dfs
% 
%         

function cp2mp
%MATLAB Tour Partial Function Help:  qft_con
%
%  CP2MP Convert complex number to magnitude/phase.
%        [M,P]=CP2MP(CP) takes the complex numbers matrix and returns
%        the magnitude matrix in M and phase matrix in P.  Magnitude is
%        arithmetic and phase data is radians
% 
%        Rows and columns in a matrix correspond to cases and
%        frequencies, respectively

function mp2cp
%MATLAB Tour Partial Function Help:  qft_con
%
%  MP2CP Convert magnitude/phase matrix to complex matrix.
%        CP=MP2CP(M,P) takes the magnitude/phase matrix and returns
%        the complex data in CP.
% 
%        Rows and columns in the matrix correspond to cases and
%        frequencies, respectively.

function qftdemo
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTDEMO Demonstration facility.
%          QFTDEMO provides a GUI for the demonstration files included with
%          the toolbox.
% 
%          Each demonstration has a matching example file QFTEX# where #
%          ranges from 1-15.

function qftex1
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX1 Main Example.

function qftex2
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX2 QFT Tracking.

function qftex3
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX3 Non-parametric uncertainty.

function qftex4
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX4 Classical design for fixed plant.

function qftex5
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX5 ACC benchmark.

function qftex6
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX6 Missile.

function qftex7
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX7 Cascaded: Inner-outer.

function qftex8
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX8 Cascaded: Outer-inner.

function qftex9
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX9 Uncertain flexible mechanism.

function qftex10
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX10 Inverted pendulum.

function qftex11
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX11 Active vibration isolation.

function qftex12
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX12 Main example - discrete-time.

function qftex13
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX13 QFT tracking - discrete-time.

function qftex14
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX14 CD mechanism - sampled-data.

function qftex15
%MATLAB Tour Partial Function Help:  qft_con
%
%  QFTEX15 2x2 MIMO.

